==> 0.0.1.tar.gz: lib/src/game_analytics.dart <==
library game_analytics;

import 'dart:async';

import 'package:flutter/services.dart';

part 'enums.dart';

class GameAnalytics {
  static const MethodChannel _channel = const MethodChannel('game_analytics');

  static void setBaseUrl(String url) {
    _channel.invokeMethod('setBaseUrl', {'url': url});
  }

  static void configureAvailableCustomDimensions01(String customDimensions) {
    _channel.invokeMethod('configureAvailableCustomDimensions01',
        {'customDimensions': customDimensions});
  }

  static void configureAvailableCustomDimensions02(String customDimensions) {
    _channel.invokeMethod('configureAvailableCustomDimensions02',
        {'customDimensions': customDimensions});
  }

  static void configureAvailableCustomDimensions03(String customDimensions) {
    _channel.invokeMethod('configureAvailableCustomDimensions03',
        {'customDimensions': customDimensions});
  }

  static void configureAvailableResourceCurrencies(String resourceCurrencies) {
    _channel.invokeMethod('configureAvailableResourceCurrencies',
        {'resourceCurrencies': resourceCurrencies});
  }

  static void configureAvailableResourceItemTypes(String resourceItemTypes) {
    _channel.invokeMethod('configureAvailableResourceItemTypes',
        {'resourceItemTypes': resourceItemTypes});
  }

  static void configureBuild(String build) {
    _channel.invokeMethod('configureBuild', {'build': build});
  }

  static void configureSdkGameEngineVersion(String sdkGameEngineVersion) {
    _channel.invokeMethod('configureSdkGameEngineVersion',
        {'sdkGameEngineVersion': sdkGameEngineVersion});
  }

  static void configureGameEngineVersion(String gameEngineVersion) {
    _channel.invokeMethod(
        'configureGameEngineVersion', {'gameEngineVersion': gameEngineVersion});
  }

  static void configureAutoDetectAppVersion(bool flag) {
    _channel.invokeMethod('configureAutoDetectAppVersion', {'flag': flag});
  }

  static void configureUserId(String uId) {
    _channel.invokeMethod('configureUserId', {'uId': uId});
  }

  static void initialize(
      {required String gameKey, required String gameSecret}) {
    // _setCallbacks();
    _channel.invokeMethod(
        'initialize', {'gameKey': gameKey, 'gameSecret': gameSecret});
  }

  static void addBusinessEvent({
    required String currency,
    required int amount,
    required String itemType,
    required String itemId,
    required String cartType,
    String receipt = '',
    String store = '',
    String signature = '',
  }) {
    _channel.invokeMethod('addBusinessEvent', {
      'currency': currency,
      'amount': amount,
      'itemType': itemType,
      'itemId': itemId,
      'cartType': cartType,
      'receipt': receipt,
      'store': store,
      'signature': signature,
    });
  }

  static void addResourceEvent({
    required GAResourceFlowType flowType,
    required String currency,
    required int amount,
    required String itemType,
    required String itemId,
  }) {
    _channel.invokeMethod('addResourceEvent', {
      'flowType': flowType,
      'currency': currency,
      'amount': amount,
      'itemType': itemType,
      'itemId': itemId,
    });
  }

  static void addProgressionEvent({
    required GAProgressionStatus progressionStatus,
    required String progression01,
    String progression02 = '',
    String progression03 = '',
    double? score,
  }) {
    _channel.invokeMethod('addProgressionEvent', {
      'progressionStatus': progressionStatus,
      'progression01': progression01,
      'progression02': progression02,
      'progression03': progression03,
      'score': score,
    });
  }

  static void addDesignEvent({
    required String eventId,
    double? value,
  }) {
    _channel.invokeMethod('addDesignEvent', {
      'eventId': eventId,
      'value': value,
    });
  }

  static void addErrorEvent({
    required GAErrorSeverity severity,
    required String message,
  }) {
    _channel.invokeMethod('addErrorEvent', {
      'severity': severity,
      'message': message,
    });
  }

  static void addAdEvent({
    required GAAdAction adAction,
    required GAAdType adType,
    required String adSdkName,
    required String adPlacement,
    GAAdError? noAdReason,
    int? duration,
  }) {
    _channel.invokeMethod('addAdEvent', {
      'adAction': adAction,
      'adType': adType,
      'adSdkName': adSdkName,
      'adPlacement': adPlacement,
      'noAdReason': noAdReason,
      'duration': duration,
    });
  }

  static void addImpressionMoPubEvent(
      String adNetworkVersion, Map<String, Object> impressionData) {
    _channel.invokeMethod('addImpressionMoPubEvent', {
      'adNetworkVersion': adNetworkVersion,
      'impressionData': impressionData,
    });
  }

  static void addImpressionFyberEvent(
      String adNetworkVersion, Map<String, Object> impressionData) {
    _channel.invokeMethod('addImpressionFyberEvent', {
      'adNetworkVersion': adNetworkVersion,
      'impressionData': impressionData,
    });
  }

  static void addImpressionIronSourceEvent(
      String adNetworkVersion, Map<String, Object> impressionData) {
    _channel.invokeMethod('addImpressionIronSourceEvent', {
      'adNetworkVersion': adNetworkVersion,
      'impressionData': impressionData,
    });
  }

  static void addImpressionTopOnEvent(
      String adNetworkVersion, Map<String, Object> impressionData) {
    _channel.invokeMethod('addImpressionTopOnEvent', {
      'adNetworkVersion': adNetworkVersion,
      'impressionData': impressionData,
    });
  }

  static void addImpressionHyperBidEvent(
      String adNetworkVersion, Map<String, Object> impressionData) {
    _channel.invokeMethod('addImpressionHyperBidEvent', {
      'adNetworkVersion': adNetworkVersion,
      'impressionData': impressionData,
    });
  }

  static void addImpressionMaxEvent(
      String adNetworkVersion, Map<String, Object> impressionData) {
    _channel.invokeMethod('addImpressionMaxEvent', {
      'adNetworkVersion': adNetworkVersion,
      'impressionData': impressionData,
    });
  }

  static void addImpressionAequusEvent(
      String adNetworkVersion, Map<String, Object> impressionData) {
    _channel.invokeMethod('addImpressionAequusEvent', {
      'adNetworkVersion': adNetworkVersion,
      'impressionData': impressionData,
    });
  }

  static void addImpressionEvent(String adNetworkName, String adNetworkVersion,
      Map<String, Object> impressionData) {
    _channel.invokeMethod('addImpressionEvent', {
      'adNetworkName': adNetworkName,
      'adNetworkVersion': adNetworkVersion,
      'impressionData': impressionData,
    });
  }

  static void setEnabledInfoLog(bool flag) {
    _channel.invokeMethod('setEnabledInfoLog', {'flag': flag});
  }

  static void setEnabledVerboseLog(bool flag) {
    _channel.invokeMethod('setEnabledVerboseLog', {'flag': flag});
  }

  static void setEnabledManualSessionHandling(bool flag) {
    _channel.invokeMethod('setEnabledManualSessionHandling', {'flag': flag});
  }

  static void setEnabledErrorReporting(bool flag) {
    _channel.invokeMethod('setEnabledErrorReporting', {'flag': flag});
  }

  static void setEnabledEventSubmission(bool flag) {
    _channel.invokeMethod('setEnabledEventSubmission', {'flag': flag});
  }

  static void setCustomDimension01(String dimension) {
    _channel.invokeMethod('setCustomDimension01', {'dimension': dimension});
  }

  static void setCustomDimension02(String dimension) {
    _channel.invokeMethod('setCustomDimension02', {'dimension': dimension});
  }

  static void setCustomDimension03(String dimension) {
    _channel.invokeMethod('setCustomDimension03', {'dimension': dimension});
  }

  static void startTimer(String key) {
    _channel.invokeMethod('startTimer', {'key': key});
  }

  static void pauseTimer(String key) {
    _channel.invokeMethod('pauseTimer', {'key': key});
  }

  static void resumeTimer(String key) {
    _channel.invokeMethod('resumeTimer', {'key': key});
  }

  static void stopTimer(String key) {
    _channel.invokeMethod('stopTimer', {'key': key});
  }

  static Future<String?> getRemoteConfigsValueAsString(String key,
      {String? defaultValue}) async {
    final result =
        await _channel.invokeMethod('getRemoteConfigsValueAsString', {
      'key': key,
      'defaultValue': defaultValue,
    });
    return result as String? ?? defaultValue;
  }

  static Future<bool> isRemoteConfigsReady() async {
    //maybe work without nullable
    final result = await _channel.invokeMethod('isRemoteConfigsReady');
    return result as bool? ?? false;
  }

  static Future<String?> getRemoteConfigsContentAsString() async {
    final result =
        await _channel.invokeMethod('getRemoteConfigsContentAsString');
    return result as String?;
  }

  static Future<String> getABTestingId() async {
    final result = await _channel.invokeMethod('getABTestingId');
    return result as String;
  }

  static Future<String> getABTestingVariantId() async {
    final result = await _channel.invokeMethod('getABTestingVariantId');
    return result as String;
  }

  static void startSession() {
    _channel.invokeMethod('startSession');
  }

  static void endSession() {
    _channel.invokeMethod('endSession');
  }

  //TODO: onRemoteConfigsUpdated
  
  // static Function()? _onRemoteConfigsUpdatedCallback;

  // static set onRemoteConfigsUpdated(Function() callback) {
  //   _onRemoteConfigsUpdatedCallback = callback;
  // }

  // static void _setCallbacks() {
  //   _channel.setMethodCallHandler((call) {
  //     if (call.method == 'onRemoteConfigsUpdated') {
  //       _onRemoteConfigsUpdatedCallback?.call();
  //     }
  //     return Future.value();
  //   });
  // }
}

==> 0.0.2.tar.gz: lib/src/game_analytics.dart <==
library game_analytics;

import 'dart:async';

import 'package:flutter/services.dart';

part 'enums.dart';

class GameAnalytics {
  static const MethodChannel _channel = const MethodChannel('game_analytics');

  /// https://gameanalytics.com/docs/s/
  static void setBaseUrl(String url) {
    _channel.invokeMethod('setBaseUrl', {'url': url});
  }

  /// https://gameanalytics.com/docs/s/article/Android-SDK-Setup#Configuration
  static void configureAvailableCustomDimensions01(
      List<String> customDimensions) {
    _channel.invokeMethod('configureAvailableCustomDimensions01',
        {'customDimensions': customDimensions});
  }

  /// https://gameanalytics.com/docs/s/article/Android-SDK-Setup#Configuration
  static void configureAvailableCustomDimensions02(
      List<String> customDimensions) {
    _channel.invokeMethod('configureAvailableCustomDimensions02',
        {'customDimensions': customDimensions});
  }

  /// https://gameanalytics.com/docs/s/article/Android-SDK-Setup#Configuration
  static void configureAvailableCustomDimensions03(
      List<String> customDimensions) {
    _channel.invokeMethod('configureAvailableCustomDimensions03',
        {'customDimensions': customDimensions});
  }

  /// https://gameanalytics.com/docs/s/article/Android-SDK-Setup#Initialization
  static void configureAvailableResourceCurrencies(
      List<String> resourceCurrencies) {
    _channel.invokeMethod('configureAvailableResourceCurrencies',
        {'resourceCurrencies': resourceCurrencies});
  }

  /// https://gameanalytics.com/docs/s/article/Android-SDK-Setup#Initialization
  static void configureAvailableResourceItemTypes(
      List<String> resourceItemTypes) {
    _channel.invokeMethod('configureAvailableResourceItemTypes',
        {'resourceItemTypes': resourceItemTypes});
  }

  /// https://gameanalytics.com/docs/s/article/Android-SDK-Setup#Configuration
  static void configureBuild(String build) {
    _channel.invokeMethod('configureBuild', {'build': build});
  }

  /// the version of SDK code used in an engine. Used for sdk_version field.
  /// !! if set then it will override the SdkWrapperVersion.
  /// example "Flutter 2.2.0"
  static void configureSdkGameEngineVersion(String sdkGameEngineVersion) {
    _channel.invokeMethod('configureSdkGameEngineVersion',
        {'sdkGameEngineVersion': sdkGameEngineVersion});
  }

  /// the version of the game engine (if used and version is available)
  static void configureGameEngineVersion(String gameEngineVersion) {
    _channel.invokeMethod(
        'configureGameEngineVersion', {'gameEngineVersion': gameEngineVersion});
  }

  /// https://gameanalytics.com/docs/s/article/Android-SDK-Setup#Configuration
  static void configureAutoDetectAppVersion(bool flag) {
    _channel.invokeMethod('configureAutoDetectAppVersion', {'flag': flag});
  }

  /// https://gameanalytics.com/docs/s/article/Android-SDK-Setup#Configuration
  static void configureUserId(String uId) {
    _channel.invokeMethod('configureUserId', {'uId': uId});
  }

  /// https://gameanalytics.com/docs/s/article/Android-SDK-Setup#Initialization
  static void initialize(
      {required String gameKey, required String gameSecret}) {
    // _setCallbacks();
    _channel.invokeMethod(
        'initialize', {'gameKey': gameKey, 'gameSecret': gameSecret});
  }

  /// https://gameanalytics.com/docs/s/article/Android-SDK-Event-Tracking#Business-Events
  static void addBusinessEvent({
    required String currency,
    required int amount,
    required String itemType,
    required String itemId,
    required String cartType,
    String receipt = '',
    String store = '',
    String signature = '',
  }) {
    _channel.invokeMethod('addBusinessEvent', {
      'currency': currency,
      'amount': amount,
      'itemType': itemType,
      'itemId': itemId,
      'cartType': cartType,
      'receipt': receipt,
      'store': store,
      'signature': signature,
    });
  }

  /// https://gameanalytics.com/docs/s/article/Android-SDK-Event-Tracking#Resource-Events
  static void addResourceEvent({
    required GAResourceFlowType flowType,
    required String currency,
    required int amount,
    required String itemType,
    required String itemId,
  }) {
    _channel.invokeMethod('addResourceEvent', {
      'flowType': flowType,
      'currency': currency,
      'amount': amount,
      'itemType': itemType,
      'itemId': itemId,
    });
  }

  /// https://gameanalytics.com/docs/s/article/Android-SDK-Event-Tracking#Progression-Events
  static void addProgressionEvent({
    required GAProgressionStatus progressionStatus,
    required String progression01,
    String progression02 = '',
    String progression03 = '',
    double? score,
  }) {
    _channel.invokeMethod('addProgressionEvent', {
      'progressionStatus': progressionStatus,
      'progression01': progression01,
      'progression02': progression02,
      'progression03': progression03,
      'score': score,
    });
  }

  /// https://gameanalytics.com/docs/s/article/Android-SDK-Event-Tracking#Design-Events
  static void addDesignEvent({
    required String eventId,
    double? value,
  }) {
    _channel.invokeMethod('addDesignEvent', {
      'eventId': eventId,
      'value': value,
    });
  }

  /// https://gameanalytics.com/docs/s/article/Android-SDK-Event-Tracking#Error-Events
  static void addErrorEvent({
    required GAErrorSeverity severity,
    required String message,
  }) {
    _channel.invokeMethod('addErrorEvent', {
      'severity': severity,
      'message': message,
    });
  }

  /// https://gameanalytics.com/docs/s/article/Android-SDK-Event-Tracking#Ad-Events
  static void addAdEvent({
    required GAAdAction adAction,
    required GAAdType adType,
    required String adSdkName,
    required String adPlacement,
    GAAdError? noAdReason,
    int? duration,
  }) {
    _channel.invokeMethod('addAdEvent', {
      'adAction': adAction,
      'adType': adType,
      'adSdkName': adSdkName,
      'adPlacement': adPlacement,
      'noAdReason': noAdReason,
      'duration': duration,
    });
  }

  /// https://gameanalytics.com/docs/s/article/Android-SDK-Event-Tracking#Impression-Events
  static void addImpressionMoPubEvent(
      String adNetworkVersion, Map<String, Object> impressionData) {
    _channel.invokeMethod('addImpressionMoPubEvent', {
      'adNetworkVersion': adNetworkVersion,
      'impressionData': impressionData,
    });
  }

  /// https://gameanalytics.com/docs/s/article/Android-SDK-Event-Tracking#Impression-Events
  static void addImpressionFyberEvent(
      String adNetworkVersion, Map<String, Object> impressionData) {
    _channel.invokeMethod('addImpressionFyberEvent', {
      'adNetworkVersion': adNetworkVersion,
      'impressionData': impressionData,
    });
  }

  /// https://gameanalytics.com/docs/s/article/Android-SDK-Event-Tracking#Impression-Events
  static void addImpressionIronSourceEvent(
      String adNetworkVersion, Map<String, Object> impressionData) {
    _channel.invokeMethod('addImpressionIronSourceEvent', {
      'adNetworkVersion': adNetworkVersion,
      'impressionData': impressionData,
    });
  }

  /// https://gameanalytics.com/docs/s/article/Android-SDK-Event-Tracking#Impression-Events
  static void addImpressionTopOnEvent(
      String adNetworkVersion, Map<String, Object> impressionData) {
    _channel.invokeMethod('addImpressionTopOnEvent', {
      'adNetworkVersion': adNetworkVersion,
      'impressionData': impressionData,
    });
  }

  /// https://gameanalytics.com/docs/s/article/Android-SDK-Event-Tracking#Impression-Events
  static void addImpressionHyperBidEvent(
      String adNetworkVersion, Map<String, Object> impressionData) {
    _channel.invokeMethod('addImpressionHyperBidEvent', {
      'adNetworkVersion': adNetworkVersion,
      'impressionData': impressionData,
    });
  }

  /// https://gameanalytics.com/docs/s/article/Android-SDK-Event-Tracking#Impression-Events
  static void addImpressionMaxEvent(
      String adNetworkVersion, Map<String, Object> impressionData) {
    _channel.invokeMethod('addImpressionMaxEvent', {
      'adNetworkVersion': adNetworkVersion,
      'impressionData': impressionData,
    });
  }

  /// https://gameanalytics.com/docs/s/article/Android-SDK-Event-Tracking#Impression-Events
  static void addImpressionAequusEvent(
      String adNetworkVersion, Map<String, Object> impressionData) {
    _channel.invokeMethod('addImpressionAequusEvent', {
      'adNetworkVersion': adNetworkVersion,
      'impressionData': impressionData,
    });
  }

  /// https://gameanalytics.com/docs/s/article/Android-SDK-Event-Tracking#Impression-Events
  static void addImpressionEvent(String adNetworkName, String adNetworkVersion,
      Map<String, Object> impressionData) {
    _channel.invokeMethod('addImpressionEvent', {
      'adNetworkName': adNetworkName,
      'adNetworkVersion': adNetworkVersion,
      'impressionData': impressionData,
    });
  }

  /// https://gameanalytics.com/docs/s/article/Android-SDK-Advanced-Features
  static void setEnabledInfoLog(bool flag) {
    _channel.invokeMethod('setEnabledInfoLog', {'flag': flag});
  }

  /// https://gameanalytics.com/docs/s/article/Android-SDK-Advanced-Features
  static void setEnabledVerboseLog(bool flag) {
    _channel.invokeMethod('setEnabledVerboseLog', {'flag': flag});
  }

  /// https://gameanalytics.com/docs/s/article/Android-SDK-Advanced-Features
  static void setEnabledManualSessionHandling(bool flag) {
    _channel.invokeMethod('setEnabledManualSessionHandling', {'flag': flag});
  }

  /// https://gameanalytics.com/docs/s/article/Android-SDK-GameOps
  static void setEnabledErrorReporting(bool flag) {
    _channel.invokeMethod('setEnabledErrorReporting', {'flag': flag});
  }

  /// https://gameanalytics.com/docs/s/article/Android-SDK-Setup
  static void setEnabledEventSubmission(bool flag) {
    _channel.invokeMethod('setEnabledEventSubmission', {'flag': flag});
  }

  /// https://gameanalytics.com/docs/s/article/Android-SDK-GameOps#Custom-Dimensions
  static void setCustomDimension01(String dimension) {
    _channel.invokeMethod('setCustomDimension01', {'dimension': dimension});
  }

  /// https://gameanalytics.com/docs/s/article/Android-SDK-GameOps#Custom-Dimensions
  static void setCustomDimension02(String dimension) {
    _channel.invokeMethod('setCustomDimension02', {'dimension': dimension});
  }

  /// https://gameanalytics.com/docs/s/article/Android-SDK-GameOps#Custom-Dimensions
  static void setCustomDimension03(String dimension) {
    _channel.invokeMethod('setCustomDimension03', {'dimension': dimension});
  }

  /// https://gameanalytics.com/docs/s/article/Android-SDK-Event-Tracking
  static void startTimer(String key) {
    _channel.invokeMethod('startTimer', {'key': key});
  }

  /// https://gameanalytics.com/docs/s/article/Android-SDK-Event-Tracking
  static void pauseTimer(String key) {
    _channel.invokeMethod('pauseTimer', {'key': key});
  }

  /// https://gameanalytics.com/docs/s/article/Android-SDK-Event-Tracking
  static void resumeTimer(String key) {
    _channel.invokeMethod('resumeTimer', {'key': key});
  }

  /// https://gameanalytics.com/docs/s/article/Android-SDK-Event-Tracking
  static void stopTimer(String key) {
    _channel.invokeMethod('stopTimer', {'key': key});
  }

  /// https://gameanalytics.com/docs/s/article/A-B-Testing-Integration
  static Future<String?> getRemoteConfigsValueAsString(String key,
      {String? defaultValue}) async {
    final result =
        await _channel.invokeMethod('getRemoteConfigsValueAsString', {
      'key': key,
      'defaultValue': defaultValue,
    });
    return result as String? ?? defaultValue;
  }

  /// https://gameanalytics.com/docs/s/article/A-B-Testing-Integration
  static Future<bool> isRemoteConfigsReady() async {
    //maybe work without nullable
    final result = await _channel.invokeMethod('isRemoteConfigsReady');
    return result as bool? ?? false;
  }

  /// https://gameanalytics.com/docs/s/article/A-B-Testing-Integration
  static Future<String?> getRemoteConfigsContentAsString() async {
    final result =
        await _channel.invokeMethod('getRemoteConfigsContentAsString');
    return result as String?;
  }

  /// https://gameanalytics.com/docs/s/article/Android-SDK-GameOps
  static Future<String> getABTestingId() async {
    final result = await _channel.invokeMethod('getABTestingId');
    return result as String;
  }

  /// https://gameanalytics.com/docs/s/article/Android-SDK-GameOps
  static Future<String> getABTestingVariantId() async {
    final result = await _channel.invokeMethod('getABTestingVariantId');
    return result as String;
  }

  /// https://gameanalytics.com/docs/s/article/Android-SDK-Advanced-Features
  static void startSession() {
    _channel.invokeMethod('startSession');
  }

  /// https://gameanalytics.com/docs/s/article/Android-SDK-Advanced-Features
  static void endSession() {
    _channel.invokeMethod('endSession');
  }

  //TODO: onRemoteConfigsUpdated

  // static Function()? _onRemoteConfigsUpdatedCallback;

  // static set onRemoteConfigsUpdated(Function() callback) {
  //   _onRemoteConfigsUpdatedCallback = callback;
  // }

  // static void _setCallbacks() {
  //   _channel.setMethodCallHandler((call) {
  //     if (call.method == 'onRemoteConfigsUpdated') {
  //       _onRemoteConfigsUpdatedCallback?.call();
  //     }
  //     return Future.value();
  //   });
  // }
}
